==> qt-creator-2.6.2-src.tar.gz: qt-creator-2.6.2-src/src/plugins/cpptools/cppfunctionsfilter.cpp <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "cppfunctionsfilter.h"

using namespace CppTools::Internal;

CppFunctionsFilter::CppFunctionsFilter(CppModelManager *manager)
    : CppLocatorFilter(manager)
{
    setShortcutString(QString(QLatin1Char('m')));
    setIncludedByDefault(false);

    search.setSymbolsToSearchFor(SearchSymbols::Functions);
    search.setSeparateScope(true);
}

CppFunctionsFilter::~CppFunctionsFilter()
{
}

==> qt-creator-2.8.1-src.tar.gz: qt-creator-2.8.1-src/src/plugins/cpptools/cppfunctionsfilter.cpp <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "cppfunctionsfilter.h"

using namespace CppTools::Internal;

CppFunctionsFilter::CppFunctionsFilter(CppModelManager *manager)
    : CppLocatorFilter(manager)
{
    setId("Methods");
    setDisplayName(tr("C++ Methods and Functions"));
    setShortcutString(QString(QLatin1Char('m')));
    setIncludedByDefault(false);

    search.setSymbolsToSearchFor(SymbolSearcher::Functions);
    search.setSeparateScope(true);
}

CppFunctionsFilter::~CppFunctionsFilter()
{
}
